#!/bin/bash

NAME=$(basename $PWD)
DATE=$(sed    -n '/^%global gh_date/{s/.* //;p}'    $NAME.spec)
OWNER=$(sed   -n '/^%global gh_owner/{s/.* //;p}'   $NAME.spec)
PROJECT=$(sed -n '/^%global gh_project/{s/.* //;p}' $NAME.spec)
VERSION=$(sed -n '/^%global upstream_version/{s/.* //;p}'  $NAME.spec)
PREVER=$(sed -n '/^%global upstream_prever/{s/.* //;p}'  $NAME.spec)
COMMIT=$(sed  -n '/^%global gh_commit/{s/.* //;p}'  $NAME.spec)
SHORT=${COMMIT:0:7}

DATE=$(date -d "$DATE -5 days" +%Y-%m-%d)

if [ -f $NAME-$VERSION$PREVER-$SHORT.tgz ]; then
	echo Skip $NAME-$VERSION$PREVER-$SHORT.tgz
else
	echo -e "\nCreate git snapshot\nName=$NAME, Owner=$OWNER, Project=$PROJECT, Version=$VERSION$PREVER, Date=$DATE\n"

	echo "Cloning..."
	rm -rf $PROJECT-$COMMIT
	git clone --branch 4.x --shallow-since=$DATE https://github.com/$OWNER/$PROJECT.git $PROJECT-$COMMIT || exit 1

	echo "Getting commit..."
	pushd $PROJECT-$COMMIT
		git checkout $COMMIT || echo exit 1
		cp composer.json ../composer.json
	popd

	echo "Archiving..."
	tar czf $NAME-$VERSION$PREVER-$SHORT.tgz --exclude-vcs $PROJECT-$COMMIT

	echo "Cleaning..."
	rm -rf $PROJECT-$COMMIT

	echo "Done."
fi
